@@ -179,7 +179,7 @@ class JacTests(TestCaseHelper, TestCase):
         test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
-        edges = list(gph.get_all_edges())
+        edges = list(gph.get_all_architypes()[1].values())
         self.assertEqual(len(edges), 3)
         edge_names = [edges[0].name, edges[1].name, edges[2].name]
         self.assertIn("generic", edge_names)
@@ -194,7 +194,7 @@ class JacTests(TestCaseHelper, TestCase):
         test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
-        edges = list(gph.get_all_edges())
+        edges = gph.get_all_architypes()[1].values()
         self.assertEqual(len(edges), 0)
 
     def test_multiple_edged_between_nodes_delete_all_specific(self):
@@ -205,7 +205,7 @@ class JacTests(TestCaseHelper, TestCase):
         test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
-        edges = list(gph.get_all_edges())
+        edges = gph.get_all_architypes()[1].values()
         self.assertEqual(len(edges), 1)
 
     def test_multiple_edged_between_nodes_delete_all_labeled(self):
@@ -216,7 +216,7 @@ class JacTests(TestCaseHelper, TestCase):
         test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
-        edges = list(gph.get_all_edges())
+        edges = gph.get_all_architypes()[1].values()
         self.assertEqual(len(edges), 3)
 
     def test_multiple_edged_between_nodes_delete_filtered(self):
@@ -227,7 +227,7 @@ class JacTests(TestCaseHelper, TestCase):
         test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
-        edges = list(gph.get_all_edges())
+        edges = gph.get_all_architypes()[1].values()
         self.assertEqual(len(edges), 5)
 
     def test_generic_can_be_used_to_specify_generic_edges(self):
@@ -238,7 +238,7 @@ class JacTests(TestCaseHelper, TestCase):
         test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
-        edges = list(gph.get_all_edges())
+        edges = gph.get_all_architypes()[1].values()
         self.assertEqual(len(edges), 2)
 
     def test_can_disconnect_multi_nodes_simultaneously(self):
@@ -249,7 +249,7 @@ class JacTests(TestCaseHelper, TestCase):
         test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
-        edges = list(gph.get_all_edges())
+        edges = gph.get_all_architypes()[1].values()
         self.assertEqual(len(edges), 2)
 
     def test_can_connect_multi_nodes_simultaneously(self):
@@ -260,7 +260,7 @@ class JacTests(TestCaseHelper, TestCase):
         test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
-        edges = list(gph.get_all_edges())
+        edges = gph.get_all_architypes()[1].values()
         self.assertEqual(len(edges), 4)
 
     def test_can_disconnect_multi_nodes_advanced(self):
@@ -271,7 +271,7 @@ class JacTests(TestCaseHelper, TestCase):
         test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
-        edges = list(gph.get_all_edges())
+        edges = gph.get_all_architypes()[1].values()
         self.assertEqual(len(edges), 3)
 
     def test_accessing_edges_basic(self):
@@ -282,7 +282,7 @@ class JacTests(TestCaseHelper, TestCase):
         test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
-        edges = list(list(gph.get_all_edges()))
+        edges = list(gph.get_all_architypes()[1].values())
         if edges[0].name == "apple":
             self.assertEqual(edges[0].context["v1"], 7)
             self.assertEqual(edges[1].context["x1"], 8)
@@ -298,7 +298,7 @@ class JacTests(TestCaseHelper, TestCase):
         test_walker = sent.run_architype("init")
         test_walker.prime(gph)
         test_walker.run()
-        nodes = gph.get_all_nodes()
+        nodes = gph.get_all_architypes()[0].values()
         self.assertEqual(len(nodes), 3)
         num = 0
         for i in nodes:
